<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CreateLibraryItem</name>
    <message>
        <location filename="../CreateLibraryItem.js" line="+49"/>
        <source>Reference Point</source>
        <translatorcomment>--google--
Wskaż punkt odniesienia
Kopiuje obiekty do schowka z punktem odniesienia
Wycina obiekty z punktem odniesienia</translatorcomment>
        <translation>Punkt odniesienia</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Save library item as...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zapisz element kolekcji jako...</translation>
    </message>
    <message>
        <location filename="../CreateLibraryItemInit.js" line="+2"/>
        <source>&amp;Create Library Item</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>U&amp;twórz element kolekcji</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Create library item from selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tworzy element kolekcji z zaznaczenia</translation>
    </message>
</context>
</TS>
